package dk.apaq.framework.repository.jpa;

import javax.persistence.EntityManager;
import dk.apaq.framework.repository.RepositoryListener;
import org.springframework.transaction.annotation.Transactional;

/**
 * This class extends EntityManagerCrud which holds all the logic. This instance
 * makes sure that when intantiated via Spring the create, update and delete
 * methods are marked as
 * <code>Transactional</code>.
 *
 * @author michaelzachariassenkrog
 */
public class EntityManagerRepositoryForSpring<BEANTYPE,IDTYPE> extends EntityManagerRepository<BEANTYPE,IDTYPE> {

    
    public EntityManagerRepositoryForSpring(EntityManager em, Class clazz) {
        super(em, clazz);
    }

    /**
     * Method suitable for setting af default listener directly via Spring.
     */
    public void setInitialListener(RepositoryListener<BEANTYPE,IDTYPE> listener) {
        addListener(listener);
    }
    
    @Override
    @Transactional(readOnly = true)
    public BEANTYPE findOne(IDTYPE id) {
        return super.findOne(id);
    }

    @Override
    @Transactional
    public BEANTYPE save(BEANTYPE entity) {
        return super.save(entity);
    }
    
    @Override
    @Transactional
    public void delete(BEANTYPE entity) {
        super.delete(entity);
    }

    @Override
    @Transactional
    public void deleteById(IDTYPE id) {
        super.deleteById(id);
    }

    
}
